// Generated by gmmproc 2.50.1 -- DO NOT MODIFY!
#ifndef _GSTREAMERMM_FDSRC_H
#define _GSTREAMERMM_FDSRC_H

#include <gstreamermmconfig.h>

#ifndef GSTREAMERMM_DISABLE_DEPRECATED


#include <glibmm/ustring.h>
#include <sigc++/sigc++.h>

// Generated by generate_plugin_gmmproc_file. Don't edit this file.


#include <gstreamermm/pushsrc.h>
#include <gstreamermm/urihandler.h>


#ifndef DOXYGEN_SHOULD_SKIP_THIS
using GstFdSrc = struct _GstFdSrc;
using GstFdSrcClass = struct _GstFdSrcClass;
#endif /* DOXYGEN_SHOULD_SKIP_THIS */


#ifndef DOXYGEN_SHOULD_SKIP_THIS
namespace Gst
{ class FdSrc_Class; } // namespace Gst
#endif //DOXYGEN_SHOULD_SKIP_THIS

namespace Gst
{

/** A Wrapper for the fdsrc plugin.
 * Please note that not all plug-ins are available on all systems so care
 * must be taken that they exist before they are used otherwise there will
 * be errors and possibly a crash.
 *
 * @ingroup GstPlugins
 * @deprecated Plugins API is deprecated, and should not be used in a new code.
 */

class FdSrc
: public Gst::PushSrc, public Gst::URIHandler
{
  
#ifndef DOXYGEN_SHOULD_SKIP_THIS

public:
  using CppObjectType = FdSrc;
  using CppClassType = FdSrc_Class;
  using BaseObjectType = GstFdSrc;
  using BaseClassType = GstFdSrcClass;

  // noncopyable
  FdSrc(const FdSrc&) = delete;
  FdSrc& operator=(const FdSrc&) = delete;

private:  friend class FdSrc_Class;
  static CppClassType fdsrc_class_;

protected:
  explicit FdSrc(const Glib::ConstructParams& construct_params);
  explicit FdSrc(GstFdSrc* castitem);

#endif /* DOXYGEN_SHOULD_SKIP_THIS */

public:

  FdSrc(FdSrc&& src) noexcept;
  FdSrc& operator=(FdSrc&& src) noexcept;

  ~FdSrc() noexcept override;

  /** Get the GType for this class, for use with the underlying GObject type system.
   */
  static GType get_type()      G_GNUC_CONST;

#ifndef DOXYGEN_SHOULD_SKIP_THIS


  static GType get_base_type() G_GNUC_CONST;
#endif

  ///Provides access to the underlying C GObject.
  GstFdSrc*       gobj()       { return reinterpret_cast<GstFdSrc*>(gobject_); }

  ///Provides access to the underlying C GObject.
  const GstFdSrc* gobj() const { return reinterpret_cast<GstFdSrc*>(gobject_); }

  ///Provides access to the underlying C instance. The caller is responsible for unrefing it. Use when directly setting fields in structs.
  GstFdSrc* gobj_copy();

private:

  
protected:
  FdSrc();
  explicit FdSrc(const Glib::ustring& name);

public:
  /** Creates a new fdsrc plugin with a unique name.
   */
  
  static Glib::RefPtr<FdSrc> create();


  /** Creates a new fdsrc plugin with the given name.
   */
  
  static Glib::RefPtr<FdSrc> create(const Glib::ustring& name);


  /** An open file descriptor to read from.
   *
   * @return A PropertyProxy that allows you to get or set the value of the property,
   * or receive notification when the value of the property changes.
   */
  Glib::PropertyProxy< int > property_fd() ;

/** An open file descriptor to read from.
   *
   * @return A PropertyProxy_ReadOnly that allows you to get the value of the property,
   * or receive notification when the value of the property changes.
   */
  Glib::PropertyProxy_ReadOnly< int > property_fd() const;

  /** Post a message after timeout microseconds (0 = disabled).
   *
   * @return A PropertyProxy that allows you to get or set the value of the property,
   * or receive notification when the value of the property changes.
   */
  Glib::PropertyProxy< guint64 > property_timeout() ;

/** Post a message after timeout microseconds (0 = disabled).
   *
   * @return A PropertyProxy_ReadOnly that allows you to get the value of the property,
   * or receive notification when the value of the property changes.
   */
  Glib::PropertyProxy_ReadOnly< guint64 > property_timeout() const;


public:

public:
  //C++ methods used to invoke GTK+ virtual functions:

protected:
  //GTK+ Virtual Functions (override these to change behaviour):

  //Default Signal Handlers::


};

} // namespace Gst


namespace Glib
{
  /** A Glib::wrap() method for this object.
   *
   * @param object The C instance.
   * @param take_copy False if the result should take ownership of the C instance. True if it should take a new copy or ref.
   * @result A C++ instance that wraps this C instance.
   *
   * @relates Gst::FdSrc
   */
  Glib::RefPtr<Gst::FdSrc> wrap(GstFdSrc* object, bool take_copy = false);
}


#endif // GSTREAMERMM_DISABLE_DEPRECATED


#endif /* _GSTREAMERMM_FDSRC_H */

