// Generated by gmmproc 2.50.1 -- DO NOT MODIFY!
#ifndef _GSTREAMERMM_VIDEOOVERLAY_P_H
#define _GSTREAMERMM_VIDEOOVERLAY_P_H


#include <glibmm/private/interface_p.h>

namespace Gst
{

class VideoOverlay_Class : public Glib::Interface_Class
{
public:
  using CppObjectType = VideoOverlay;
  using BaseObjectType = GstVideoOverlay;
  using BaseClassType = GstVideoOverlayInterface;
  using CppClassParent = Glib::Interface_Class;

  friend class VideoOverlay;

  const Glib::Interface_Class& init();

  static void iface_init_function(void* g_iface, void* iface_data);

  static Glib::ObjectBase* wrap_new(GObject*);

protected:

  //Callbacks (default signal handlers):
  //These will call the *_impl member methods, which will then call the existing default signal callbacks, if any.
  //You could prevent the original default signal handlers being called by overriding the *_impl method.

  //Callbacks (virtual functions):
  static void set_window_handle_vfunc_callback(GstVideoOverlay* self, guintptr handle);
  static void expose_vfunc_callback(GstVideoOverlay* self);
  static void handle_events_vfunc_callback(GstVideoOverlay* self, gboolean handle_events);
  static void set_render_rectangle_vfunc_callback(GstVideoOverlay* self, gint x, gint y, gint width, gint height);
};


} // namespace Gst


#endif /* _GSTREAMERMM_VIDEOOVERLAY_P_H */

